@@ -945,7 +945,7 @@ def 排名(数据源: list, 第几个: int):
 
     from Fishconsole import files
 
-    b = files.强制类型检测(数据源, "list")
+    b = files.强制类型检测(数据源, ["list"])
     if b:
         第几个 = int(第几个)
         第几个 = 第几个 - 1
@@ -1175,7 +1175,7 @@ def 数字字母化(模式, 数据源):
     from Fishconsole import files
     模式 = str(模式)
     if 模式 == "1":
-        强制类型检测 = files.强制类型检测(数据源, "int")
+        强制类型检测 = files.强制类型检测(数据源, ["int"])
         if 强制类型检测:
             空容器 = ""
             数据源 = list(str(数据源))
@@ -1205,7 +1205,7 @@ def 数字字母化(模式, 数据源):
             logs.安全退出("类型错误")
     if 模式 == "2":
         空容器 = ""
-        强制类型检测 = files.强制类型检测(数据源, "str")
+        强制类型检测 = files.强制类型检测(数据源, ["str"])
         if 强制类型检测:
             数据源 = list(str(数据源))
             计数器 = 0
@@ -1265,7 +1265,7 @@ def 任务平均分配(任务数量, 数据源: list):
         任务数量 = int(任务数量)
     except:
         logs.安全退出("任务平均分配》任务数量类型检测》请指定正确的类型")
-    if files.强制类型检测(数据源, "list"):
+    if files.强制类型检测(数据源, ["list",'range']):
         for _ in 数据源:
             计数器 = 计数器 + 1
         try:
